#!/usr/bin/perl -I/usr/sausalito/perl
#
# $Id: vz_backup_vps_parse.pl, v 1.0.0.1 Sun 08 Nov 2009 09:31:56 PM CET mstauber Exp $
# Copyright 2006-2009 Solarspeed Ltd. All rights reserved.
#
# Handler which polls all Vserver_Backup objects and removes or writes the config file 
# /etc/vz/aconf/vps-vps-backup.conf which contains flat file info about which VPS is to 
# be backed up when and where to.
#
# It also performs the following two tasks:
#
# - Cleans up CODB to find and remove redundant database objects related to the backup.
# - Makes sure only backup database objects for VPS's with active file area are taken into account.

$whatami = "handler";
#$whatami = "constructor";

use CCE;
use POSIX qw(isalpha);
my $cce = new CCE;
my $conf = '/var/lib/cobalt';

if ($whatami eq "handler") {
    $cce->connectfd();
}
else {
    $cce->connectuds();
}

$oid = $cce->event_oid();
$obj = $cce->event_object();

$vserver_cronVPSConfig = "/etc/vz/aconf/vps-vps-backup.conf";

if (!-d "/etc/vz/aconf") {
    system("/bin/mkdir /etc/vz/aconf");
}

@oids = $cce->find('Vserver_Backup');

if (defined($oids[0])) {

    open(CRON, ">$vserver_cronVPSConfig") || die "Can't write to $vserver_cronVPSConfig";
    print CRON "# vzbackup - Aventurin{e} Backup \n";
    print CRON "# DO NOT EDIT! THIS FILE IS GENERATED AUTOMATICALLY THROUGH THE GUI!\n";
    print CRON "\n";

    $a = 0;
    foreach $line (@oids) {
            ($ok, $system) = $cce->get($line);
	    $CONFIG[$a][0] = $system->{'vpsid'};
	    $CONFIG[$a][1] = $system->{'ip'};
	    $CONFIG[$a][2] = $system->{'hostname'};
	    $CONFIG[$a][3] = $system->{'LBpresent'};
	    $CONFIG[$a][4] = $system->{'LRpresent'};
	    $CONFIG[$a][5] = $system->{'LRtimestamp'};
	    $CONFIG[$a][6] = $system->{'LBtimestamp'};
	    $CONFIG[$a][7] = $system->{'VserverBackupLocalEnabled'};
	    $CONFIG[$a][8] = $system->{'VserverBackupRemoteEnabled'};
	    $CONFIG[$a][9] = $system->{'VserverBackupEnabled'};
	    $CONFIG[$a][10] = $system->{'VserverBackupRemoteAuthority'};

	    # Check if VPS has a file area:
	    if ( -d "/vz/private/" . $system->{'vpsid'} ) {
		$CONFIG[$a][11] = "1";
	    }
	    else {
		$CONFIG[$a][11] = "0";
	    }

	    # Find out if we have multiple 'Vserver_Backup' objects for the same VPSID:
	    (@sys_double) = $cce->find('Vserver_Backup', { 'vpsid' => $CONFIG[$a][0] });
	    if ($#sys_double > 0) {
		# More than one 'Vserver_Backup' found for this VPSID!
		# Remove the last element from the array to keep one of the double entries:
		pop(@sys_double);
		# Walk through the rest of the double entries and destroy them:
		foreach $double (@sys_double) {
			($ok) = $cce->destroy($double);
		}
	    }		

	    # Print the line out to the config file if the VPS has a file area - if not, destroy the object:
	    if ($CONFIG[$a][11] == "1") {
		# VPS has file area, so this is legit:
		print CRON "$CONFIG[$a][0]&$CONFIG[$a][1]&$CONFIG[$a][2]&$CONFIG[$a][3]&$CONFIG[$a][4]&$CONFIG[$a][5]&$CONFIG[$a][6]&$CONFIG[$a][7]&$CONFIG[$a][8]&$CONFIG[$a][9]&$CONFIG[$a][10]\n";
	    }
	    else {
		# VPS has no file area, so it is a ghost. Destroy the object:
		($ok) = $cce->destroy($line);
	    }
	    $a++;
    }
    print CRON "\n";
    print CRON "\n";
    close CRON;    
    system("/bin/chmod 600 $vserver_cronVPSConfig");
}
else {
    system("/bin/rm -f $vserver_cronVPSConfig");
}

$cce->bye('SUCCESS');
exit(0);

